@@ -76,17 +76,18 @@ class NotificationHandler(object):
         http://developer.ebay.com/DevZone/XML/docs/WebHelp/wwhelp/wwhimpl/common/html/wwhelp.htm?context=eBay_XML_API&file=WorkingWithNotifications-Receiving_Platform_Notifications.html
         """
         
-        # get a float timestamp
-        timestamp = time.mktime(message.Timestamp.timetuple())
+        floattime = time.mktime(message.Timestamp.timetuple())
+        timestamp_str = ebay_timestamp_string(message.Timestamp)
+        log.info('%s -> %s', message.Timestamp, timestamp_str)
         if not settings.DEBUG:
             # check timestamp is within 10 minutes of current time
-            diff_seconds = math.fabs(time.time() - timestamp)
+            diff_seconds = math.fabs(time.time() - floattime)
             if diff_seconds > 600:
                 raise TimestampOutOfBounds("Payload timestamp was %s seconds away from current time." % diff_seconds)
         
         # make hash
         m = hashlib.md5()
-        m.update(ebay_timestamp_string(message.Timestamp))
+        m.update(timestamp_str)
         m.update(ebaysuds_config.get('keys', 'dev_id'))
         if self.client.sandbox:
             conf_section = 'sandbox_keys'
@@ -96,6 +97,6 @@ class NotificationHandler(object):
         m.update(ebaysuds_config.get(conf_section, 'cert_id'))
         computed_hash = base64.standard_b64encode(m.hexdigest())
         if computed_hash != signature:
-            raise InvalidSignature(signature)
+            raise InvalidSignature("%s != %s" % (computed_hash, signature))
 
         return True
